Installation guide — Cabby 0.1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.5 documentation »

# Installation guide

## Install Python

OpenTAXII works with Python version 2.7, which you can download here or with your operating system’s package manager.

You can verify that Python is installed by typing `python` from your shell; you should see something like:

    $ python
    Python 2.7.6 (default, Sep  9 2014, 15:04:36)
    [GCC 4.2.1 Compatible Apple LLVM 6.0 (clang-600.0.39)] on darwin
    Type "help", "copyright", "credits" or "license" for more information.
    >>>

## Install Cabby

To sandbox the project and protect system-wide python it is recommended to install Cabby into a virtual environment (virtualenv):

Create a virtual environment named venv:

    $ virtualenv venv

Where `venv` is a directory to place the new environment

Activate this environment:

    $ source venv/bin/activate
    (venv) $

You can now install the latest Cabby release from the Python Package Index (PyPI) using `pip`:

    (venv) $ pip install cabby

Note

Since Cabby has libtaxii as a dependency, the system libraries libtaxii requires need to be installed. Check libtaxii documentation for the details.

To install Cabby from source files: download a tarball, unpack it and install it manually with `python setup.py install`.

## Versioning

Releases of Cabby are given major.minor.revision version numbers, where major and minor correspond to the roadmap Intelworks has. The revision number is used to indicate a bug fix only release.

Next steps

Continue with the User guide to see how to use cabby.

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.5 documentation »